spoon.objTypes

Package spoon :: Module objTypes |
[show private | hide private]
[frames | no frames]

## Module spoon.objTypes

Variable Summary
`int` | `LMTYPE_INIT` = 0
`int` | `LMTYPE_NETWORK` = 1
`int` | `LMTYPE_NETWORK_PROTO` = 2
`int` | `NMTYPE_MESSAGING` = 0

Variable Details

    ### LMTYPE_INIT Type: `int` Value:
        0

    ### LMTYPE_NETWORK Type: `int` Value:
        1

    ### LMTYPE_NETWORK_PROTO Type: `int` Value:
        2

    ### NMTYPE_MESSAGING Type: `int` Value:
        0

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net